import BN from 'bn.js';
import { Account } from 'near-api-js';
import { StorageBalance } from './types';
export * from './types';
export declare const NEAR_DECIMALS = 24;
export declare function storageBalanceOf(account: Account, contractId: string, accountId?: string): Promise<StorageBalance<BN> | null>;
export interface StorageDepositArgs {
    /**
     * The account to deposit for. Omit to use the calling account.
     */
    accountId?: string;
    /**
     * If set to true, a spec-compliant contract will keep the minimum required
     * deposit and refund the remainder, if any.
     */
    registrationOnly?: boolean;
    /**
     * Amount to deposit. Can be a human-readble number representing NEAR or a BN representing yoctoNEAR
     */
    amount: number | BN;
}
/**
 * Deposit storage balance
 *
 * @param account Account to call with
 * @param contractId Contract to deposit into
 * @param args
 * @param gas Gas allowance, defaults to 100TGas
 */
export declare function storageDeposit(account: Account, contractId: string, args: StorageDepositArgs, gas?: BN): Promise<{
    executionOutcome: import("near-api-js/lib/providers").FinalExecutionOutcome;
    result: StorageBalance<BN>;
}>;
